.. geochemistrypy_test documentation master file, created by
   sphinx-quickstart on Sun Oct 23 18:52:20 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Welcome to Geochemistry π 
=======================================================================================

.. toctree::
   :maxdepth: 1
   :caption: Introduction

   Introduction/Introduction.md

.. toctree::
   :maxdepth: 1
   :caption: Installation

   Installation.md

.. toctree::
   :maxdepth: 1
   :caption: Citing this work

.. toctree::
   :maxdepth: 3
   :caption: Model Example

   Model Example/Data_Preprocessing/Data Preprocessing.md
   Model Example/Clustering/Clustering.md
   Model Example/Classification/classification.md
   Model Example/Decomposition/decomposition.md
   Model Example/Regression/Regression.md
   

.. toctree::
   :maxdepth: 2
   :caption: Contact Us

   Contact us/bug_template.md
   Contact us/Q&A.md
   Contact us/Join us.md

.. toctree::
   :maxdepth: 2
   :caption: Contributing

   Contributing/Code Conduct.md
   Contributing/Contributor.md

.. toctree::
   :maxdepth: 2
   :caption: User Guide

   User Guide.md

.. toctree::
   :maxdepth: 2
   :caption: Developer Guide

   Developer/Deployment.md
   Developer/Git.md
   Developer/Docker Deployment.md

.. toctree::
   :maxdepth: 2
   :caption: API

   python_apis/api.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
